@@ -18,8 +18,15 @@ from shapely.geometry import Polygon, MultiPolygon
 from . import globals
 from .utils import log
 from .projection import project_graph
+from .save_load import graph_to_gdfs
 from .core import graph_from_address, graph_from_point, bbox_from_point
 
+# folium is an optional dependency for the plot_route_folium function
+try:
+    import folium
+except ImportError as e:
+    folium = None
+
 
 def plot_shape(gdf, fc='#cbe0f0', ec='#999999', linewidth=1, alpha=1, figsize=(6,6), margin=0.02, axis_off=True):
     """
@@ -66,7 +73,7 @@ def plot_shape(gdf, fc='#cbe0f0', ec='#999999', linewidth=1, alpha=1, figsize=(6
     return fig, ax
 
 
-def get_edge_colors_by_attr(G, attr, num_bins=5, cmap='spectral', start=0.1, stop=0.9):
+def get_edge_colors_by_attr(G, attr, num_bins=5, cmap='viridis', start=0, stop=1):
     """
     Get a list of edge colors by binning some continuous-variable attribute into quantiles
     
@@ -190,12 +197,10 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02, axis_off
     node_Xs = [float(node['x']) for node in G.node.values()]
     node_Ys = [float(node['y']) for node in G.node.values()]
     
-    # get north, south, east, west values either from bbox parameter or from min/max node coordinate values
+    # get north, south, east, west values either from bbox parameter or from the spatial extent of the edges' geometries
     if bbox is None:
-        north = max(node_Ys)
-        south = min(node_Ys)
-        east = max(node_Xs)
-        west = min(node_Xs)
+        edges = graph_to_gdfs(G, nodes=False, fill_edge_geometry=True)
+        west, south, east, north = edges.total_bounds
     else:
         north, south, east, west = bbox
     
@@ -206,7 +211,7 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02, axis_off
     
     # create the figure and axis
     fig, ax = plt.subplots(figsize=(fig_width, fig_height), facecolor=bgcolor)
-    ax.set_axis_bgcolor(bgcolor)
+    ax.set_facecolor(bgcolor)
     
     # draw the edges as lines from node to node
     start_time = time.time()
@@ -242,8 +247,13 @@ def plot_graph(G, bbox=None, fig_height=6, fig_width=None, margin=0.02, axis_off
     # configure axis appearance
     ax.get_xaxis().get_major_formatter().set_useOffset(False)
     ax.get_yaxis().get_major_formatter().set_useOffset(False)
+    
+    # if axis_off, turn off the axis display set the margins to zero and point the ticks in so there's no space around the plot
     if axis_off:
         ax.axis('off')
+        ax.margins(0)
+        ax.tick_params(which='both', direction='in')
+        fig.canvas.draw()
     
     # annotate the axis with node IDs if annotate=True
     if annotate:
@@ -360,9 +370,59 @@ def plot_graph_route(G, route, bbox=None, fig_height=6, fig_width=None, margin=0
     return fig, ax
     
     
+def plot_route_folium(G, route, tiles='cartodbpositron', zoom=1, fit_bounds=True, 
+                      route_color='#ff0000', route_width=5, route_opacity=1):
+    """
+    Plot a route on an interactive folium web map.
+    
+    Parameters
+    ----------
+    G : graph
+    route : list, the route as a list of nodes
+    tiles : string, name of a folium tileset
+    zoom : int, initial zoom level for the map
+    fit_bounds : bool, if True, fit the map to the boundaries of the route's edges
+    route_color : string, color of the route's line
+    route_width : numeric, width of the route's line
+    route_opacity : numeric, opacity of the route lines
+    
+    Returns
+    -------
+    route_map : folium.folium.Map
+    
+    """
+    
+    # check if we were able to import folium successfully
+    if not folium:
+        raise ImportError('The folium package must be installed to use this optional feature.')
+    
+    # create geojson of the route edges
+    gdf_edges = graph_to_gdfs(G, nodes=False, fill_edge_geometry=True)
+    route_nodes = list(zip(route[:-1], route[1:]))
+    index = [gdf_edges[(gdf_edges['u']==u) & (gdf_edges['v']==v)].index[0] for u, v in route_nodes]
+    gdf_route_edges = gdf_edges.loc[index]
+    route_geojson = gdf_route_edges.to_json()
+    
+    # get route centroid
+    x, y = gdf_route_edges.unary_union.centroid.xy
+    route_centroid = (y[0], x[0])
+    
+    # get map tiles and draw route
+    route_map = folium.Map(location=route_centroid, zoom_start=zoom, tiles=tiles)
+    route_map.choropleth(geo_str=route_geojson, line_color=route_color, line_weight=route_width, line_opacity=route_opacity)
+    
+    # if fit_bounds is True, fit the map to the bounds of the route by passing list of lat-lng points as [southwest, northeast]
+    if fit_bounds:
+        tb = gdf_route_edges.total_bounds
+        bounds = [(tb[1], tb[0]), (tb[3], tb[2])]
+        route_map.fit_bounds(bounds)
+    
+    return route_map
+    
+    
 def plot_figure_ground(address=None, point=None, dist=805, network_type='drive_service',
                        street_widths=None, default_width=4, fig_length=8, edge_color='w', bgcolor='#333333',
-                       filename=None, file_format='png', show=False, save=True, close=True):
+                       filename=None, file_format='png', show=False, save=True, close=True, dpi=300):
     """
     Plot a figure-ground diagram of a street network, defaulting to one square mile.
     
@@ -382,6 +442,7 @@ def plot_figure_ground(address=None, point=None, dist=805, network_type='drive_s
     show : bool, if True, show the figure
     save : bool, if True, save the figure as an image file to disk
     close : close the figure (only if show equals False) to prevent display
+    dpi : int, the resolution of the image file if saving
     
     Returns
     -------
@@ -431,7 +492,11 @@ def plot_figure_ground(address=None, point=None, dist=805, network_type='drive_s
     # plot the figure
     fig, ax = plot_graph(G, bbox=bbox_proj, fig_height=fig_length, margin=0, node_size=0, 
                          edge_linewidth=edge_linewidths, edge_color=edge_color, bgcolor=bgcolor, 
-                         show=show, save=save, close=close, filename=filename, file_format=file_format)
+                         show=show, save=save, close=close, filename=filename, file_format=file_format, dpi=dpi)
+    
+    # make everything square
+    ax.set_aspect('equal')
+    fig.canvas.draw()
     
     return fig, ax
     
